/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.bundu.bezugswst;

import org.apache.log4j.Logger;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.artifacts.common.utils.XMLUtils;
import org.dive4elements.river.artifacts.D4EArtifact;
import org.dive4elements.river.artifacts.states.WQAdapted;
import org.w3c.dom.Element;

/**
 * State to input W/Q data for fixings
 *
 * @author <a href="mailto:aheinecke@intevation.de">Andre Heinecke</a>
 */
public class BunduWstWQFixing extends WQAdapted {

    private static final long serialVersionUID = 1L;

    /** The log used in this state. */
    private static Logger log = Logger.getLogger(BunduWstWQFixing.class);

    @Override
    protected String getUIProvider() {
        return "bundu_wst_wq_panel";
    }

    @Override
    public boolean validate(final Artifact artifact) throws IllegalArgumentException {

        // Validation is done on client side. No wrong inputs should arrive here.
        // Validation in Super is not suitable for this case
        return true;
    }

    // adding bezugsjahr and dauer to client
    @Override
    protected Element[] createItems(final XMLUtils.ElementCreator ec, final Artifact artifact, final String name, final CallContext context) {

        final Element[] defaultElements = super.createItems(ec, artifact, name, context);
        if (name.equals("bundu.wst.mode")) { // random-name eines DataItems vom state (s. bundu.xml), sodass verhindert wird, dass an alle DataItems
                                             // length+bezugsjahr drangehängt werden
            final BunduAccess access = new BunduAccess((D4EArtifact) artifact);

            final int bezugsjahr = access.getBezugsJahr();
            final int qSeriesLength = access.getQSeriesLength();
            final String[] keys = new String[] { "ignore_q_series_length", "ignore_bezugsjahr" };
            final String[] values = new String[] { String.valueOf(qSeriesLength), String.valueOf(bezugsjahr) };

            return FixationChoice.appendElements(ec, defaultElements, keys, values);
        } else
            return defaultElements;
    }
}